package com.bcxin.message.service;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.bcxin.message.common.utils.IdGeneratorSnowflake;
import com.bcxin.message.dao.mapper.MsgAdminUserSenderMapper;
import com.bcxin.message.dtos.request.BindSenderRequest;
import com.bcxin.message.entity.MsgAdminUserSender;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.Date;

/**
 * description：消息中心用户发送者表 service
 * author：linchunpeng
 * date：2023/11/17
 */
@Slf4j
@Service
public class MsgAdminUserSenderService extends ServiceImpl<MsgAdminUserSenderMapper, MsgAdminUserSender> {

    @Autowired
    private MsgAdminUserSenderMapper dao;
    @Autowired
    private IdGeneratorSnowflake snowflake;



    /**
     * description：appid绑定sender
     * author：linchunpeng
     * date：2023/11/21
     */
    @Transactional
    public void bindSender(BindSenderRequest request) {
        MsgAdminUserSender msgAdminUserSender = this.findByAppidAndSender(request.getAppid(), request.getSender());
        if (request.getOperateType() == 1) {
            //绑定
            if (msgAdminUserSender == null) {
                this.bind(request.getAppid(), request.getSender(), request.getSenderType());
            }
        } else {
            //解绑
            if (msgAdminUserSender != null) {
                this.removeById(msgAdminUserSender.getId());
            }
        }
    }

    /**
     * description：通过appid 与 sender，查询绑定关系
     * author：linchunpeng
     * date：2023/11/21
     */
    public MsgAdminUserSender findByAppidAndSender(String appid, String sender) {
        LambdaQueryWrapper<MsgAdminUserSender> lqw = Wrappers.lambdaQuery();
        lqw.eq(MsgAdminUserSender::getAppid, appid);
        lqw.eq(MsgAdminUserSender::getSender, sender);
        return dao.selectOne(lqw);
    }

    /**
     * description：创建绑定sender关系
     * author：linchunpeng
     * date：2023/11/21
     */
    private void bind(String appid, String sender, String senderType) {
        MsgAdminUserSender msgAdminUserSender = new MsgAdminUserSender();
        msgAdminUserSender.setId(snowflake.snowflakeId());
        msgAdminUserSender.setAppid(appid);
        msgAdminUserSender.setSender(sender);
        msgAdminUserSender.setSenderType(senderType);
        msgAdminUserSender.setCreateTime(new Date());
        msgAdminUserSender.setUpdateTime(new Date());
        this.save(msgAdminUserSender);
    }

}
