package com.bcxin.message.service;

import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.bcxin.message.common.utils.IdGeneratorSnowflake;
import com.bcxin.message.dao.mapper.MsgExceptionMapper;
import com.bcxin.message.entity.MsgException;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.Date;

/**
 * description：消息中心异常表 service
 * author：linchunpeng
 * date：2023/11/17
 */
@Slf4j
@Service
public class MsgExceptionService extends ServiceImpl<MsgExceptionMapper, MsgException> {

    @Autowired
    private MsgExceptionMapper dao;
    @Autowired
    private IdGeneratorSnowflake snowflake;

    /**
     * description：创建异常记录
     * author：linchunpeng
     * date：2023/11/17
     */
    @Transactional
    public void createException(String requestId, String appid, String requestUrl, String requestParam, String exceptionInfo) {
        MsgException msgException = new MsgException();
        msgException.setId(snowflake.snowflakeId());
        msgException.setRequestId(requestId);
        msgException.setAppid(appid);
        msgException.setRequestUrl(requestUrl);
        msgException.setRequestParam(requestParam);
        if (StringUtils.isNotBlank(exceptionInfo) && exceptionInfo.length() > 5000) {
            exceptionInfo = exceptionInfo.substring(0, 4999);
        }
        msgException.setExceptionInfo(exceptionInfo);
        msgException.setCreateTime(new Date());
        msgException.setUpdateTime(new Date());
        this.save(msgException);
    }

}
