package com.bcxin.message.service;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.bcxin.message.common.utils.IdGeneratorSnowflake;
import com.bcxin.message.dao.mapper.MsgRequestLogMapper;
import com.bcxin.message.entity.MsgRequestLog;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.Date;

/**
 * description：消息中心请求日志表 service
 * author：linchunpeng
 * date：2023/11/17
 */
@Slf4j
@Service
public class MsgRequestLogService extends ServiceImpl<MsgRequestLogMapper, MsgRequestLog> {

    @Autowired
    private MsgRequestLogMapper dao;
    @Autowired
    private IdGeneratorSnowflake snowflake;

    /**
     * description：创建请求日志
     * author：linchunpeng
     * date：2023/11/17
     */
    @Transactional
    public void createLog(String requestId, String appid, String requestUrl, String requestParam) {
        MsgRequestLog msgRequestLog = new MsgRequestLog();
        msgRequestLog.setId(snowflake.snowflakeId());
        msgRequestLog.setRequestId(requestId);
        msgRequestLog.setAppid(appid);
        msgRequestLog.setRequestUrl(requestUrl);
        msgRequestLog.setRequestParam(requestParam);
        msgRequestLog.setCreateTime(new Date());
        msgRequestLog.setUpdateTime(new Date());
        this.save(msgRequestLog);
    }

    /**
     * description：更新请求结果
     * author：linchunpeng
     * date：2023/11/17
     */
    @Transactional
    public void updateRequestResult(String requestId, String requestResult) {
        LambdaQueryWrapper<MsgRequestLog> lqw = Wrappers.lambdaQuery();
        lqw.eq(MsgRequestLog::getRequestId, requestId);
        MsgRequestLog msgRequestLog = dao.selectOne(lqw);
        if (msgRequestLog != null) {
            msgRequestLog.setRequestResult(requestResult);
        }
        this.updateById(msgRequestLog);
    }

}
