package com.bcxin.message.strategy.message;

import com.bcxin.message.common.CommonConstant;
import com.bcxin.message.common.utils.SpringContextUtils;
import com.bcxin.message.strategy.message.impl.ChannelSendUserTextMsg;
import com.bcxin.message.strategy.message.impl.RobotSendGroupTextMsg;
import com.bcxin.message.strategy.message.impl.RobotSendUserTextMsg;

/**
 * 发送消息策略工厂
 */
public class SendMessageStrategyFactory {

    /**
     * 根据key，获取机器人策略接口实现类
     */
    public static SendMessageStrategy getInstance(String key) {
        switch (key) {
            case CommonConstant.ROBOT_STRATEGY_KEY_SEND_USER_TEXT_MSG:
                //机器人-发送用户文本消息
                return SpringContextUtils.getBean(RobotSendUserTextMsg.class);
            case CommonConstant.ROBOT_STRATEGY_KEY_SEND_GROUP_TEXT_MSG:
                //机器人-发送群组文本消息
                return SpringContextUtils.getBean(RobotSendGroupTextMsg.class);
            case CommonConstant.CHANNEL_STRATEGY_KEY_SEND_USER_TEXT_MSG:
                //频道-发送用户文本消息
                return SpringContextUtils.getBean(ChannelSendUserTextMsg.class);
        }
        throw new RuntimeException(String.format("机器人策略工厂：获取策略异常，key：%s", key));
    }

    /**
     * 根据发送类型和消息类型，获取机器人策略接口实现类
     */
    public static SendMessageStrategy getInstance(String senderType, String targetType, String messageType) {
        switch (senderType) {
            case CommonConstant.MSG_SEND_TYPE_ROBOT:
                //机器人
                switch (targetType) {
                    case CommonConstant.MSG_TARGET_TYPE_USER:
                        //用户
                        switch (messageType) {
                            case CommonConstant.MSG_MESSAGE_TYPE_TEXT:
                                //发送用户文本消息
                                return SpringContextUtils.getBean(RobotSendUserTextMsg.class);
                        }
                    case CommonConstant.MSG_TARGET_TYPE_GROUP:
                        //群组
                        switch (messageType) {
                            case CommonConstant.MSG_MESSAGE_TYPE_TEXT:
                                //发送群组文本消息
                                return SpringContextUtils.getBean(RobotSendGroupTextMsg.class);
                        }
                }
            case CommonConstant.MSG_SEND_TYPE_CHANNEL:
                //频道
                switch (targetType) {
                    case CommonConstant.MSG_TARGET_TYPE_USER:
                        //用户
                        switch (messageType) {
                            case CommonConstant.MSG_MESSAGE_TYPE_TEXT:
                                //发送用户文本消息
                                return SpringContextUtils.getBean(ChannelSendUserTextMsg.class);
                        }
                }

        }
        throw new RuntimeException(String.format("机器人策略工厂：获取策略异常，senderType：%s，targetType：%s，messageType：%s",
                senderType, targetType, messageType));
    }
}
