package com.bcxin.message.strategy.message.impl;

import cn.wildfirechat.common.ErrorCode;
import cn.wildfirechat.pojos.Conversation;
import cn.wildfirechat.pojos.MessagePayload;
import cn.wildfirechat.pojos.SendMessageResult;
import cn.wildfirechat.sdk.RobotService;
import cn.wildfirechat.sdk.model.IMResult;
import com.alibaba.fastjson.JSONObject;
import com.bcxin.message.common.CommonConstant;
import com.bcxin.message.dtos.request.SendRobotMessageRequest;
import com.bcxin.message.service.MsgSendLogService;
import com.bcxin.message.strategy.message.SendMessageStrategy;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

/**
 * description：机器人发送群组文本消息
 * author：linchunpeng
 * date：2023/11/7
 */
@Slf4j
@Service
public class RobotSendGroupTextMsg implements SendMessageStrategy {

    @Value("${ye-huo.im-server.url}")
    private String appServerUrl;
    @Autowired
    private MsgSendLogService msgSendLogService;


    /**
     * description：发送消息
     * author：linchunpeng
     * date：2023/11/21
     */
    @Override
    public void sendMessage(SendRobotMessageRequest request) {
        String sender = request.getSender();
        RobotService robotService = new RobotService(appServerUrl, sender, sender.concat("_secret"));
        for (String targetId : request.getTargetIds()) {
            int sendSuccess = 0;
            String sendResultStr = "";
            try {
                //会话
                Conversation conversation = new Conversation();
                //会话类型，0一对一的会话类型，1群组会话类型，2聊天室会话类型，3一对多的会话类型，5密聊会话类型
                conversation.setType(1);
                conversation.setTarget(targetId);
                //会话线路，会话线路可以更加方便的过滤会话
                //比如同一个app中不同部门可以使用不同的line区分
                // 或者可以设计不同的场景使用不同的line等
                // 如果没有这种特殊需求，使用0值就可以
                conversation.setLine(0);
                //消息载体
                MessagePayload payload = new MessagePayload();
                //内容类型，1文本消息内容，2语音消息内容，3图片消息内容，4位置消息内容，5文件消息内容，6视频消息内容，7动态表情消息内容，8图文消息混排内容
                payload.setType(1);
                //消息可搜索内容
                payload.setSearchableContent(request.getMessage());
                //消息内容
                payload.setContent(request.getMessage());
                //消息推送内容
                payload.setPushContent(request.getMessage());

                IMResult<SendMessageResult> sendResult = robotService.sendMessage(sender, conversation, payload);
                sendResultStr = JSONObject.toJSONString(sendResult);
                log.info("请求id：{}，机器人发送群组文本消息，发送结果：{}", request.getRequestId(), sendResultStr);
                if (sendResult != null && sendResult.getErrorCode() == ErrorCode.ERROR_CODE_SUCCESS) {
                    log.info("请求id：{}，机器人发送群组文本消息，发送成功", request.getRequestId());
                    sendSuccess = 1;
                } else {
                    log.info("请求id：{}，机器人发送群组文本消息，发送失败", request.getRequestId());
                }
            } catch (Exception e) {
                e.printStackTrace();
                log.error("请求id：{}，机器人发送群组文本消息，发送失败", e.getMessage(), e);
                sendResultStr = e.getMessage();
            }
            msgSendLogService.record(request, CommonConstant.ROBOT_STRATEGY_KEY_SEND_GROUP_TEXT_MSG, sendSuccess, sendResultStr);
        }
    }
}
